@@ -14,6 +14,10 @@
 //qDebug() << "test";
 //qDebug() << "number:" << QString::number(signalnr);
 #include <QMaemo5InformationBox>
+#include <QSystemDeviceInfo>
+
+QTM_USE_NAMESPACE
+//using namespace QtMobility;
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -117,6 +121,7 @@ void MainWindow::save_ini()
     settings.beginGroup("Forward");
     settings.setValue("forward", ui->checkBox_forward->isChecked());
     settings.setValue("landev", ui->comboBox_landev->currentIndex());
+    settings.setValue("cinvalid", ui->checkBox_invalidcon->isChecked());
     settings.setValue("masklan", ui->radioButton_masqlan->isChecked());
     settings.setValue("masksub", ui->radioButton_masqsub->isChecked());
     settings.setValue("maskip", ui->lineEdit_masqsub->text());
@@ -204,7 +209,7 @@ void MainWindow::load_ini()
             settings.endGroup();
             settings.beginGroup("Forward");
             ui->checkBox_forward->setChecked(settings.value("forward").toBool());
-            ui->checkBox_invalidcon->setChecked(settings.value("dinvalid").toBool());
+            ui->checkBox_invalidcon->setChecked(settings.value("cinvalid").toBool());
             ui->comboBox_landev->setCurrentIndex(settings.value("landev").toInt());
             ui->radioButton_masqlan->setChecked(settings.value("masklan").toBool());
             ui->radioButton_masqsub->setChecked(settings.value("masksub").toBool());
@@ -1786,6 +1791,14 @@ void MainWindow::on_tabWidget_route_currentChanged(int index)
         //if (tmp=="") tmp="Not available";
         ui->textEdit_routet->setText(tmp);
     }
+    else if (index==3) {
+        getrev();
+        getos();
+        getkernel();
+        getimei();
+        getimsi();
+        getpower();
+    }
 
 }
 
@@ -1904,3 +1917,85 @@ void MainWindow::on_pushButton_ipinfo_clicked()
     ui->label_bnepip->setText(getip("bnep0"));
     ui->label_wlanip->setText(getip("wlan0"));
 }
+
+void MainWindow::getpower()
+{
+    QSystemDeviceInfo s;
+    ui->label_power->setText("Power: " + QString::number(s.batteryLevel())+ "%");
+}
+
+void MainWindow::getimsi()
+{
+    QSystemDeviceInfo s;
+    ui->label_imsi->setText("IMSI: " + s.imsi());
+}
+
+void MainWindow::getimei()
+{
+    QSystemDeviceInfo s;
+    ui->label_imei->setText("IMEI: " + s.imei());
+}
+
+void MainWindow::getos()
+{
+    QByteArray envname = qgetenv("OSSO_VERSION");
+    ui->label_os->setText("OS: \t" + envname);
+}
+
+/*void MainWindow::getos()
+{
+    QSystemInfo s;
+    QString os=s.version(QSystemInfo::Os);
+    QString firm=s.version(QSystemInfo::Firmware);
+    ui->label_os->setText("OS: PR" + os + "\tFirmware: " + firm);
+}*/
+
+void MainWindow::getkernel()
+{
+    QString prog = "sh";//shell
+    QStringList arguments;
+    arguments << "-c" << "uname -r";
+    QProcess* process = new QProcess(this);
+    process->start(prog, arguments);
+    process->waitForFinished();
+    QString tmp=process->readAll();
+    if (tmp=="") tmp="Not available";
+    //else tmp=tmp.left(tmp.count()-1);
+    ui->label_kernel->setText("Kernel: \t" + tmp);
+}
+
+void MainWindow::getrev()
+{
+    QString prog = "sh";//shell
+    QStringList arguments;
+    arguments << "-c" << "cat /proc/cpuinfo";
+    QProcess* process = new QProcess(this);
+    process->start(prog, arguments);
+    process->waitForFinished();
+    QStringList list = QString::fromLatin1(process->readAllStandardOutput()).split("\n");
+    QRegExp rx("Hardware*");
+    rx.setPatternSyntax(QRegExp::Wildcard);
+    int posfind = list.indexOf(rx);
+    if (posfind!= -1) {
+        QString ablage(list.at(posfind));
+        int t=ablage.indexOf(":");
+        ablage=ablage.right(ablage.count() - t - 2);
+        ui->label_board->setText("Hardware: \t" + ablage);
+    }
+    else ui->textEdit_3->setText("not found");
+    rx.setPattern("Revision*");
+    posfind = list.indexOf(rx);
+    if (posfind!= -1) {
+        QString ablage(list.at(posfind));
+        int t=ablage.indexOf(":");
+        ablage=ablage.right(ablage.count() - t - 2);
+        ui->label_rev->setText("Revision: \t" + ablage);
+    }
+    else ui->textEdit_3->setText("not found");
+    /*
+    int anzlist = list.count();
+    ui->textEdit_3->append(QString::number(anzlist));
+    for (int i = 1; i < anzlist; ++i){
+    ui->textEdit_3->append(list.at(i));
+    }*/
+}
