@@ -83,6 +83,12 @@ private slots:
     QString getip(QString dev);
     QString getfilter(QString ftype);
     QString getpidof(QString pname);
+    void getrev();
+    void getimei();
+    void getimsi();
+    void getpower();
+    void getos();
+    void getkernel();
     void deleteSettings(QString);
     void on_tabWidget_route_currentChanged(int index);
     void on_pushButton_ipinfo_clicked();
